@@ -192,7 +192,22 @@ class DOC_TEMPLATE:
             name=NAME,
             consolidate_blocks=CONSOLIDATE_BLOCKS
     )
-
+    delimited = dict(
+            doc='Given a file path or file-like object, write the :obj:`Frame` as delimited text.',
+            fp='A file path, PathLib instance, or file-like object.',
+            delimiter='delimiter: Character to be used for delimiterarating elements.',
+            include_index='include_index: If True, the index will be written.',
+            include_index_name='include_index_name: If including columns, populate the row above the index with the index ``name``. Cannot be True if ``include_columns_name`` is ``True``.',
+            include_columns='include_columns: If ``True``, the columns will be written.',
+            include_columns_name='include_columns_name: If including index, populate the column to the left of the columns with the columns ``name``. Cannot be True if ``include_index_name`` is True.',
+            encoding='encoding: Encoding type to be used when opening the file.',
+            line_terminator='line_terminator: The string used to terminate lines.',
+            quote_char='quote_char: A one-character string used to quote fields containing special characters, such as the ``delimiter`` or ``quote_char``, or which contain new-line characters.',
+            quote_double='quote_double: Controls how instances of quote_char appearing inside a field should themselves be quoted. When ``True``, the character is doubled. When ``False``, the ``escape_char`` is used as a prefix to the ``quote_char``. It defaults to True.',
+            escape_char='escape_char: A one-character string used by the writer to escape the delimiter if quoting is set to QUOTE_NONE and the quotechar if quote_double is False.',
+            quoting='quoting: Controls when quotes should be generated. It can take on any of the QUOTE_* constants from the standard library csv module.',
+            store_filter='store_filter: A :obj:`StoreFilter` instance.',
+            )
     duplicated = dict(
             exclude_first='exclude_first: Boolean to select if the first duplicated value is excluded.',
             exclude_last='exclude_last: Boolean to select if the last duplicated value is excluded.',
@@ -268,6 +283,7 @@ class DOC_TEMPLATE:
             container="container: Container to be inserted.",
             fill_value='fill_value: A value to be used to fill space after reindexing the new container.'
             )
+
     join = dict(
             left_depth_level="left_depth_level: Specify one or more left index depths to include in the join predicate.",
             left_columns="left_columns: Specify one or more left columns to include in the join predicate.",
@@ -337,7 +353,7 @@ class DOC_TEMPLATE:
             )
 
     relabel = dict(
-            doc ='''Return a new :obj:`{class_name}` with transformed labels on the index. The size and ordering of the data is never chagned in a relabeling operation. The resulting index must be unique.
+            doc ='''Return a new :obj:`{class_name}` with transformed labels on the index. The size and ordering of the data is never changed in a relabeling operation. The resulting index must be unique.
             ''',
             count='''A positive integer drops that many outer-most levels; a negative integer drops that many inner-most levels.''',
             level='''A hashable value to be used as a new root level, extending or creating an ``IndexHierarchy``''',
@@ -367,6 +383,12 @@ class DOC_TEMPLATE:
             columns='''Number of labels to select from the columns.''',
             seed='''Initial state of random selection.''',
             )
+    searchsorted = dict(
+            doc='Given a sorted :obj:`Series`, return the {label_type} position(s) at which insertion in ``values`` would retain sort order.',
+            values='values: a single value, or iterable of values.',
+            side_left='side_left: If True, the index of the first suitable location found is given, else return the last such index. If matching an existing value, `side_left==True` will return that position, `side_left==Right` will return the next position (or the length).',
+            fill_value='fill_value: A value to be used to fill the label beyond the last label.',
+            )
     selector = dict(
             key_loc=LOC_SELECTOR,
             key_iloc=ILOC_SELECTOR,
