@@ -31,6 +31,7 @@ from static_frame.core.index_base import IndexBase
 from static_frame.core.index_level import IndexLevel
 from static_frame.core.index_level import IndexLevelGO
 from static_frame.core.index_auto import RelabelInput
+from static_frame.core.index_datetime import IndexDatetime
 
 from static_frame.core.node_dt import InterfaceDatetime
 from static_frame.core.node_iter import IterNodeApplyType
@@ -67,6 +68,8 @@ from static_frame.core.util import union2d
 from static_frame.core.util import array2d_to_tuples
 from static_frame.core.util import iterable_to_array_2d
 from static_frame.core.util import array_sample
+from static_frame.core.util import key_to_datetime_key
+# from static_frame.core.util import array2d_to_array1d_tuples
 
 if tp.TYPE_CHECKING:
     from pandas import DataFrame #pylint: disable=W0611 #pragma: no cover
@@ -681,7 +684,6 @@ class IndexHierarchy(IndexBase):
                 container=self,
                 )
 
-
     #---------------------------------------------------------------------------
 
     def _update_array_cache(self) -> None:
@@ -915,7 +917,7 @@ class IndexHierarchy(IndexBase):
     def _drop_loc(self, key: GetItemKeyType) -> 'IndexHierarchy':
         '''Create a new index after removing the values specified by the loc key.
         '''
-        return self._drop_iloc(self.loc_to_iloc(key))
+        return self._drop_iloc(self._loc_to_iloc(key))
 
     #---------------------------------------------------------------------------
 
@@ -1045,7 +1047,7 @@ class IndexHierarchy(IndexBase):
 
     #---------------------------------------------------------------------------
 
-    def loc_to_iloc(self,
+    def _loc_to_iloc(self,
             key: tp.Union[GetItemKeyType, HLoc]
             ) -> GetItemKeyType:
         '''
@@ -1055,10 +1057,12 @@ class IndexHierarchy(IndexBase):
 
         if isinstance(key, ILoc):
             return key.key
-        elif isinstance(key, IndexHierarchy):
+
+        if isinstance(key, IndexHierarchy):
             # default iteration of IH is as tuple
             return [self._levels.leaf_loc_to_iloc(k) for k in key]
-        elif isinstance(key, np.ndarray) and key.dtype == DTYPE_BOOL:
+
+        if isinstance(key, np.ndarray) and key.dtype == DTYPE_BOOL:
             return self.positions[key]
 
         if isinstance(key, HLoc):
@@ -1071,6 +1075,17 @@ class IndexHierarchy(IndexBase):
 
         return self._levels.loc_to_iloc(key)
 
+    def loc_to_iloc(self,
+            key: tp.Union[GetItemKeyType, HLoc]
+            ) -> GetItemKeyType:
+        '''Given a label (loc) style key (either a label, a list of labels, a slice, or a Boolean selection), return the index position (iloc) style key. Keys that are not found will raise a KeyError or a sf.LocInvalid error.
+
+        Args:
+            key: a label key.
+        '''
+        # NOTE: the public method is the same as the private method for IndexHierarchy, but not for Index
+        return self._loc_to_iloc(key)
+
     def _extract_iloc(self,
             key: GetItemKeyType,
             ) -> tp.Union['IndexHierarchy', tp.Tuple[tp.Hashable]]:
@@ -1097,7 +1112,7 @@ class IndexHierarchy(IndexBase):
     def _extract_loc(self,
             key: GetItemKeyType
             ) -> tp.Union['IndexHierarchy', tp.Tuple[tp.Hashable]]:
-        return self._extract_iloc(self.loc_to_iloc(key))
+        return self._extract_iloc(self._loc_to_iloc(key))
 
     def __getitem__(self, #pylint: disable=E0102
             key: GetItemKeyType
@@ -1115,7 +1130,6 @@ class IndexHierarchy(IndexBase):
             raise KeyError('__getitem__ does not support multiple indexers')
         return IndexHierarchyAsType(self, key=key)
 
-
     #---------------------------------------------------------------------------
     # operators
 
@@ -1354,7 +1368,6 @@ class IndexHierarchy(IndexBase):
                 own_blocks=True
                 )
 
-
     def _sample_and_key(self,
             count: int = 1,
             *,
@@ -1376,6 +1389,84 @@ class IndexHierarchy(IndexBase):
                 )
         return container, key
 
+
+    @doc_inject(selector='searchsorted', label_type='iloc (integer)')
+    def iloc_searchsorted(self,
+            values: tp.Any,
+            *,
+            side_left: bool = True,
+            ) -> tp.Union[tp.Hashable, tp.Iterable[tp.Hashable]]:
+        '''
+        {doc}
+
+        Args:
+            {values}
+            {side_left}
+        '''
+        if isinstance(values, tuple):
+            match_pre = [values] # normalize a multiple selection
+            is_element = True
+        elif isinstance(values, list):
+            match_pre = values
+            is_element = False
+        else:
+            raise NotImplementedError('A single label (as a tuple) or multiple labels (as a list) must be provided.')
+
+        dt_pos = np.array([issubclass(idx_type, IndexDatetime)
+                for idx_type in self._levels.index_types()])
+        has_dt = dt_pos.any()
+
+        values_for_match = np.empty(len(match_pre), dtype=object)
+
+        for i, label in enumerate(match_pre):
+            if has_dt:
+                label = tuple(v if not dt_pos[j] else key_to_datetime_key(v)
+                        for j, v in enumerate(label))
+            values_for_match[i] = label
+
+        post = self.flat().iloc_searchsorted(values_for_match, side_left=side_left)
+        if is_element:
+            return post[0] #type: ignore [no-any-return]
+        return post #type: ignore [no-any-return]
+
+
+    @doc_inject(selector='searchsorted', label_type='loc (label)')
+    def loc_searchsorted(self,
+            values: tp.Any,
+            *,
+            side_left: bool = True,
+            fill_value: tp.Any = np.nan,
+            ) -> tp.Union[tp.Hashable, tp.Iterable[tp.Hashable]]:
+        '''
+        {doc}
+
+        Args:
+            {values}
+            {side_left}
+            {fill_value}
+        '''
+        # will return an integer or an array of integers
+        sel = self.iloc_searchsorted(values, side_left=side_left)
+
+        length = self.__len__()
+        if sel.ndim == 0 and sel == length: # an element:
+            return fill_value #type: ignore [no-any-return]
+
+        flat = self.flat().values
+        mask = sel == length
+        if not mask.any():
+            return flat[sel] #type: ignore [no-any-return]
+
+        post = np.empty(len(sel), dtype=object)
+        sel[mask] = 0 # set out of range values to zero
+        post[:] = flat[sel]
+        post[mask] = fill_value
+        post.flags.writeable = False
+        return post #type: ignore [no-any-return]
+
+
+
+
     #---------------------------------------------------------------------------
     # export
 
