@@ -881,7 +881,7 @@ class Quilt(ContainerBase, StoreClientMixin):
             bus_keys = duplicate_filter(axis_map_sub.values)
 
         for key_count, key in enumerate(bus_keys):
-            sel_component = sel[self._axis_map.index.loc_to_iloc(HLoc[key])]
+            sel_component = sel[self._axis_map.index._loc_to_iloc(HLoc[key])]
 
             if self._axis == 0:
                 component = self._bus.loc[key]._extract_array(sel_component, opposite_key) #type: ignore [attr-defined]
@@ -964,7 +964,7 @@ class Quilt(ContainerBase, StoreClientMixin):
             bus_keys = duplicate_filter(axis_map_sub.values)
 
         for key_count, key in enumerate(bus_keys):
-            sel_component = sel[self._axis_map.index.loc_to_iloc(HLoc[key])]
+            sel_component = sel[self._axis_map.index._loc_to_iloc(HLoc[key])]
 
             if self._axis == 0:
                 component = self._bus.loc[key].iloc[sel_component, opposite_key]
@@ -1019,12 +1019,12 @@ class Quilt(ContainerBase, StoreClientMixin):
         '''
         if isinstance(key, tuple):
             loc_row_key, loc_column_key = key
-            iloc_column_key = self._columns.loc_to_iloc(loc_column_key)
+            iloc_column_key = self._columns._loc_to_iloc(loc_column_key)
         else:
             loc_row_key = key
             iloc_column_key = None
 
-        iloc_row_key = self._index.loc_to_iloc(loc_row_key)
+        iloc_row_key = self._index._loc_to_iloc(loc_row_key)
         return iloc_row_key, iloc_column_key
 
     def _extract_loc(self, key: GetItemKeyTypeCompound) -> tp.Union[Series, Frame]:
@@ -1036,7 +1036,7 @@ class Quilt(ContainerBase, StoreClientMixin):
             key: GetItemKeyTypeCompound) -> tp.Tuple[GetItemKeyType, GetItemKeyType]:
         '''Handle a potentially compound key in the style of __getitem__. This will raise an appropriate exception if a two argument loc-style call is attempted.
         '''
-        iloc_column_key = self._columns.loc_to_iloc(key)
+        iloc_column_key = self._columns._loc_to_iloc(key)
         return None, iloc_column_key
 
     @doc_inject(selector='selector')
