@@ -1387,7 +1387,7 @@ class Series(ContainerOperand):
         Compatibility:
             Pandas supports taking in iterables of keys, where some keys are not found in the index; a Series is returned as if a reindex operation was performed. This is undesirable. Better instead is to use reindex()
         '''
-        iloc_key = self._index.loc_to_iloc(key)
+        iloc_key = self._index._loc_to_iloc(key)
         values = self.values[iloc_key]
 
         if not isinstance(values, np.ndarray): # if we have a single element
@@ -1435,7 +1435,7 @@ class Series(ContainerOperand):
                 )
 
     def _drop_loc(self, key: GetItemKeyType) -> 'Series':
-        return self._drop_iloc(self._index.loc_to_iloc(key))
+        return self._drop_iloc(self._index._loc_to_iloc(key))
 
     #---------------------------------------------------------------------------
 
@@ -1450,7 +1450,7 @@ class Series(ContainerOperand):
     def _extract_loc_mask(self, key: GetItemKeyType) -> 'Series':
         '''Produce a new boolean Series of the same shape, where the values selected via loc selection are True. The `name` attribute is not propagated.
         '''
-        iloc_key = self._index.loc_to_iloc(key)
+        iloc_key = self._index._loc_to_iloc(key)
         return self._extract_iloc_mask(key=iloc_key)
 
     #---------------------------------------------------------------------------
@@ -1464,7 +1464,7 @@ class Series(ContainerOperand):
     def _extract_loc_masked_array(self, key: GetItemKeyType) -> MaskedArray:
         '''Produce a new boolean Series of the same shape, where the values selected via loc selection are True.
         '''
-        iloc_key = self._index.loc_to_iloc(key)
+        iloc_key = self._index._loc_to_iloc(key)
         return self._extract_iloc_masked_array(key=iloc_key)
 
     #---------------------------------------------------------------------------
@@ -1473,7 +1473,7 @@ class Series(ContainerOperand):
         return SeriesAssign(self, key)
 
     def _extract_loc_assign(self, key: GetItemKeyType) -> 'SeriesAssign':
-        iloc_key = self._index.loc_to_iloc(key)
+        iloc_key = self._index._loc_to_iloc(key)
         return SeriesAssign(self, iloc_key)
 
     #---------------------------------------------------------------------------
@@ -1987,6 +1987,7 @@ class Series(ContainerOperand):
         values.flags.writeable = False
         return self.__class__(values, index=index, name=self._name)
 
+    #---------------------------------------------------------------------------
 
     @doc_inject(selector='argminmax')
     def loc_min(self, *,
@@ -2042,8 +2043,8 @@ class Series(ContainerOperand):
 
     @doc_inject(selector='argminmax')
     def iloc_max(self, *,
-                skipna: bool = True,
-                ) -> int:
+            skipna: bool = True,
+            ) -> int:
         '''
         Return the integer index corresponding to the maximum value.
 
@@ -2055,6 +2056,64 @@ class Series(ContainerOperand):
         '''
         return argmax_1d(self.values, skipna=skipna) #type: ignore
 
+    #---------------------------------------------------------------------------
+
+    @doc_inject(selector='searchsorted', label_type='iloc (integer)')
+    def iloc_searchsorted(self,
+            values: tp.Any,
+            *,
+            side_left: bool = True,
+            ) -> tp.Union[tp.Hashable, tp.Iterable[tp.Hashable]]:
+        '''
+        {doc}
+
+        Args:
+            {values}
+            {side_left}
+        '''
+        if not isinstance(values, str) and hasattr(values, '__len__'):
+            if not isinstance(values, np.ndarray):
+                values, _ = iterable_to_array_1d(values)
+        return np.searchsorted(self.values, #type: ignore [no-any-return]
+                values,
+                'left' if side_left else 'right',
+                )
+
+    @doc_inject(selector='searchsorted', label_type='loc (label)')
+    def loc_searchsorted(self,
+            values: tp.Any,
+            *,
+            side_left: bool = True,
+            fill_value: tp.Any = np.nan,
+            ) -> tp.Union[tp.Hashable, tp.Iterable[tp.Hashable]]:
+        '''
+        {doc}
+
+        Args:
+            {values}
+            {side_left}
+            {fill_value}
+        '''
+        sel = self.iloc_searchsorted(values, side_left=side_left)
+
+        length = self.__len__()
+        if sel.ndim == 0 and sel == length: # an element:
+            return fill_value #type: ignore [no-any-return]
+
+        mask = sel == length
+        if not mask.any():
+            return self._index.values[sel] #type: ignore [no-any-return]
+
+        post = np.empty(len(sel),
+                dtype=resolve_dtype(self._index.dtype,
+                dtype_from_element(fill_value))
+                )
+        sel[mask] = 0 # set out of range values to zero
+        post[:] = self._index.values[sel]
+        post[mask] = fill_value
+        post.flags.writeable = False
+        return post #type: ignore [no-any-return]
+
     #---------------------------------------------------------------------------
     def _insert(self,
             key: int, # iloc positions
@@ -2107,7 +2166,7 @@ class Series(ContainerOperand):
         Returns:
             :obj:`Series`
         '''
-        iloc_key = self._index.loc_to_iloc(key)
+        iloc_key = self._index._loc_to_iloc(key)
         if not isinstance(iloc_key, INT_TYPES):
             raise RuntimeError(f'Unsupported key type: {key}')
         return self._insert(iloc_key, container)
@@ -2127,7 +2186,7 @@ class Series(ContainerOperand):
         Returns:
             :obj:`Series`
         '''
-        iloc_key = self._index.loc_to_iloc(key)
+        iloc_key = self._index._loc_to_iloc(key)
         if not isinstance(iloc_key, INT_TYPES):
             raise RuntimeError(f'Unsupported key type: {key}')
         return self._insert(iloc_key + 1, container)
@@ -2214,7 +2273,7 @@ class Series(ContainerOperand):
             tp.Iterable[tp.Tuple[tp.Hashable, tp.Any]]
         '''
         if isinstance(self._index, IndexHierarchy):
-            index_values = list(array2d_to_tuples(self._index.values))
+            index_values = array2d_to_tuples(self._index.values)
         else:
             index_values = self._index.values
 
